@@ -459,6 +459,8 @@ _exc = {
     "disorganised": "disorganized",
     "distil": "distill",
     "distils": "distills",
+    "doin": "doing",
+    "doin'": "doing",
     "dramatisation": "dramatization",
     "dramatisations": "dramatizations",
     "dramatise": "dramatize",
@@ -687,6 +689,8 @@ _exc = {
     "globalises": "globalizes",
     "globalising": "globalizing",
     "glueing ": "gluing ",
+    "goin": "going",
+    "goin'":"going",
     "goitre": "goiter",
     "goitres": "goiters",
     "gonorrhoea": "gonorrhea",
@@ -733,6 +737,8 @@ _exc = {
     "harmonised": "harmonized",
     "harmonises": "harmonizes",
     "harmonising": "harmonizing",
+    "havin": "having",
+    "havin'": "having",
     "homoeopath": "homeopath",
     "homoeopathic": "homeopathic",
     "homoeopaths": "homeopaths",
@@ -924,6 +930,8 @@ _exc = {
     "localised": "localized",
     "localises": "localizes",
     "localising": "localizing",
+    "lovin": "loving",
+    "lovin'": "loving",
     "louvre": "louver",
     "louvred": "louvered",
     "louvres": "louvers ",
